@@ -19,7 +19,7 @@ Classes
     PathPlan
     Robot
     RobotSemantics
-    UrdfImporter
+    RosFileServerLoader
 
 Unit conversion
 ---------------
@@ -41,13 +41,13 @@ from .path_plan import *
 from .units import *
 from .robot import *
 from .semantics import *
-from .urdf_importer import *
+from .ros_fileserver_loader import *
 
 from .configuration import __all__ as a
 from .path_plan import __all__ as b
 from .units import __all__ as c
 from .robot import __all__ as d
 from .semantics import __all__ as e
-from .urdf_importer import __all__ as f
+from .ros_fileserver_loader import __all__ as f
 
 __all__ = a + b + c + d + e + f
